#[non_exhaustive]pub enum CanvasInteraction {
Click {
element_id: ElementId,
action: String,
},
InputSubmit {
element_id: ElementId,
value: String,
},
FormSubmit {
element_id: ElementId,
values: HashMap<String, String>,
},
CodeSubmit {
element_id: ElementId,
code: String,
language: String,
},
}Expand description
Interaction events from the canvas back to agents.
These are generated by user interaction with canvas elements and sent back to the agent via WebSocket.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Click
User clicked a button element.
InputSubmit
User submitted an input field.
FormSubmit
User submitted a form.
CodeSubmit
User submitted code from a code editor.