Module kernel

Module kernel 

Kernel configuration types.

These types are defined in clawft-types so they can be embedded in the root Config without creating a circular dependency with clawft-kernel.

Structs

ChainConfig
Local chain configuration.
ClusterNetworkConfig
Cluster networking configuration for distributed WeftOS nodes.
KernelConfig
Kernel subsystem configuration.
ResourceTreeConfig
Resource tree configuration.