KernelConfig

Struct KernelConfig 

pub struct KernelConfig {
    pub enabled: bool,
    pub max_processes: u32,
    pub health_check_interval_secs: u64,
    pub cluster: Option<ClusterNetworkConfig>,
    pub chain: Option<ChainConfig>,
    pub resource_tree: Option<ResourceTreeConfig>,
}
Kernel subsystem configuration.

Embedded in the root Config under the kernel key. All fields have sensible defaults so that existing configuration files parse without errors.

Example JSON

{
  "kernel": {
    "enabled": false,
    "max_processes": 128,
    "health_check_interval_secs": 15
  }
}

Fields

enabled: bool

Whether the kernel subsystem is enabled.

When false, kernel subsystems do not activate unless explicitly invoked via weave kernel CLI commands. Defaults to true.

max_processes: u32

Maximum number of concurrent processes in the process table.

health_check_interval_secs: u64

Interval (in seconds) between periodic health checks.

cluster: Option<ClusterNetworkConfig>

Cluster networking configuration (native coordinator nodes).

chain: Option<ChainConfig>

Local chain configuration (exochain feature).

resource_tree: Option<ResourceTreeConfig>

Resource tree configuration (exochain feature).