#[non_exhaustive]pub enum PolicyMode {
Allowlist,
Denylist,
}Expand description
Whether the command policy operates in allowlist or denylist mode.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Allowlist
Only commands whose basename appears in the allowlist are permitted.
Denylist
All commands are permitted unless they match a denylist pattern.